@@ -18,8 +18,8 @@ def get_substrings(subs: str, long_string: str) -> list[int]:
         Написать функцию, которая ищет позиции всех вхождений подстроки subs 
         в строке long_string. Номера позиций начинаются с нуля.
         Например подстрока "hello" встречается в строке "hello, world, all people hello"
-        два раза: на позиции 0 (начало строки) и 25. Т.е. для этих параметров
-        функция вернет спис
+        два раза: на позиции 0 (начало строки) и 25. Т.е. для этих исходных данных
+        функция вернет список индексов вхождений строки.
     """
     return []
 
