@@ -10,12 +10,25 @@ class VariableState:
     param_type: str
     param_value: str
 
+    def __str__(self) -> str:
+        return f"{self.param_name}={self.param_value}({self.param_type})"
+
+    def __repr__(self) -> str:
+        return self.__str__()
+
 
 @dataclass
 class TestCaseState:
     inputs: list[VariableState]
     expected: VariableState
 
+    def __str__(self) -> str:
+        inps = ",".join(str(s) for s in self.inputs)
+        return f"{self.expected}, inputs = {inps}"
+
+    def __repr__(self) -> str:
+        return self.__str__()
+
 
 @dataclass
 class PythonTaskState:
